@@ -6,10 +6,10 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use Encode qw(encode_utf8);
-use Crypt::Passphrase::Bcrypt;
+use Crypt::Passphrase::Bcrypt ();
 
 sub make_encode_sub {
   my($class, $col, $args) = @_;
@@ -20,12 +20,10 @@ sub make_encode_sub {
     cost => $cost,
   );
 
-  my $encoder = sub {
+  return sub {
     my ($plain_text) = @_;
     return $passphrase->hash_password($plain_text);
   };
-
-  return $encoder;
 }
 
 sub make_check_sub {
@@ -41,7 +39,7 @@ sub make_check_sub {
     my $col_v = $_[0]->get_column($col);
     return unless defined $col_v;
     return $passphrase->verify_password(encode_utf8($_[1]), $col_v);
-  }
+  };
 }
 
 sub _get_cost {
@@ -69,7 +67,7 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Bcrypt - Crypt::Passphrase::Bcryp
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -134,7 +132,7 @@ L<DBIx::Class::EncodedColumn>
 
 =head1 AUTHOR
 
-Guillermo Roditi (groditi) <groditi@cpan.org>
+Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
